Index: src/heap.h |
diff --git a/src/heap.h b/src/heap.h |
index a2702d35432df227d2ead5faa7ca3a1220603fb9..cdc693369aa65a083aae8a9f69a65433b825d409 100644 |
--- a/src/heap.h |
+++ b/src/heap.h |
@@ -2445,9 +2445,17 @@ class GCTracer BASE_EMBEDDED { |
return (static_cast<double>(HEAP->SizeOfObjects())) / MB; |
} |
- double start_time_; // Timestamp set in the constructor. |
- intptr_t start_size_; // Size of objects in heap set in constructor. |
- GarbageCollector collector_; // Type of collector. |
+ // Timestamp set in the constructor. |
+ double start_time_; |
+ |
+ // Size of objects in heap set in constructor. |
+ intptr_t start_object_size_; |
+ |
+ // Size of memory allocated from OS set in constructor. |
+ intptr_t start_memory_size_; |
+ |
+ // Type of collector. |
+ GarbageCollector collector_; |
// A count (including this one, e.g. the first collection is 1) of the |
// number of garbage collections. |